==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/space/messages/zh-CN/base.php <==
<?php

return [
    '<b>This space is still empty!</b>' => '<b>这个空间还是空空如也！</b>',
    '<b>This space is still empty!</b><br>Start by posting something here...' => '<b>这个空间依然是空的</b><br>开始写点什么',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>你还不是这个空间的成员，这个空间目前还没有公开内容！</b>',
    '<strong>Confirm</strong> image deletion' => '<strong>确认</strong> 删除图片',
    '<strong>Invite</strong> members' => '<strong>邀请</strong> 成员',
    '<strong>New</strong> member request' => '<strong>新</strong> 成员请求',
    '<strong>New</strong> spaces' => '<strong>新</strong>空间',
    '<strong>Request</strong> Membership' => '<strong>请求</strong> 加入空间',
    '<strong>Space</strong> followers' => '<strong>空间</strong> 关注者',
    '<strong>Space</strong> members' => '<strong>空间</strong>成员',
    '<strong>Space</strong> menu' => '<strong>空间</strong> 菜单',
    'About' => '关于',
    'Accept' => '接受',
    'Accept Invite' => '接收邀请',
    'Access to this Space is restricted. Please introduce yourself to become a member.' => '为了获得空间管理员的通过，请简短介绍一下你自己。',
    'Admin' => '管理',
    'Administrators' => '超级管理用户',
    'Archived' => '已存档',
    'As owner you cannot revoke your membership!' => '作为拥有者，你不能撤消你的会员资格',
    'Cancel' => '取 消',
    'Close' => '关 闭',
    'Color' => '颜色',
    'Could not request membership!' => '无法请求成为成员',
    'Created At' => '创建于',
    'Created By' => '创建人',
    'Decline' => '拒绝',
    'Default' => '默认',
    'Default content visibility' => '默认内容可见性',
    'Delete' => '删除',
    'Description' => '描述',
    'Do you really want to delete your profile image?' => '你真的要删除属性图片吗？',
    'Do you really want to delete your title image?' => '你真的要删除标题图片吗？',
    'Done' => '执行',
    'Email addresses' => '邮件地址',
    'Everyone can enter' => '所有人能加入',
    'Follow' => '关注',
    'Followers' => '被关注',
    'Following' => '关注',
    'Guests' => '游客',
    'Homepage' => '首页',
    'Invite' => '邀请',
    'Invite and request' => '邀请和请求',
    'Invite by email' => '通过邮件邀请',
    'Invites' => '邀请',
    'Join Policy' => '加入政策',
    'Last Visit' => '最后一次访问',
    'Login' => '登录',
    'Members' => '成员',
    'Moderators' => '版主',
    'My Space List' => '我的空间列表',
    'My space summary' => '我的空间概要',
    'Name' => '名字',
    'New user by e-mail (comma separated)' => '通过e-mail邀请新用户（以逗号分隔）',
    'New user?' => '新用户',
    'No spaces found.' => '没有发现空间。',
    'Only by invite' => '只有通过邀请',
    'Originator User ID' => '原始用户ID',
    'Owner' => '拥有者',
    'Pick users' => '选择用户',
    'Posts' => '文章',
    'Private' => '私有的',
    'Private (Invisible)' => '私有(不可见)',
    'Public' => '公共',
    'Public (Members & Guests)' => '公开 (成员 和 游客)',
    'Public (Members only)' => '公开 (仅成员)',
    'Public (Registered users only)' => '公开 (仅注册用户)',
    'Request Message' => '请求消息',
    'Role' => '角色',
    'See all' => '查看所有',
    'Send' => '发 送',
    'Settings' => '设置',
    'Show all' => '展示所有',
    'Sorry, you are not allowed to leave this space!' => '抱歉，你不允许离开该空间！',
    'Sorting' => '排序',
    'Space' => '空间',
    'Space directory' => '空间目录',
    'Space is invisible!' => '空间不可见',
    'Spaces' => '空间',
    'Status' => '状态',
    'Stream' => '动态',
    'Tags' => '标签',
    'There is no pending invite!' => '没有请求！',
    'This action is only available for workspace members!' => '此操作仅适用于空间成员！',
    'This user is already a member of this space.' => '该用户已是该空间成员。',
    'This user is not a member of this space.' => '该用户不是该空间成员。',
    'To invite users to this space, please type their names below to find and pick them.' => '邀请用户到这个空间，请键入他们的名字在下面找到并选择他们。',
    'Updated At' => '修改于',
    'Updated By' => '修改人',
    'Updated by' => '修改人',
    'User \'{username}\' is already a member of this space!' => '用户 \'{username}\' 已经是这个空间的成员了!',
    'User not found!' => '用户未找到',
    'Users' => '用户',
    'Visibility' => '可见性',
    'Visible for all (members and guests)' => '所有人可见 (成员 和 游客)',
    'You are not allowed to join this space!' => '您不可以参加这个空间！',
    'You can also invite external users, which are not registered now. Just add their e-mail addresses separated by comma.' => '您还可以邀请现在没有注册的外部用户。只需添加他们的电子邮件地址用逗号分隔。',
    'You cannot create private visible spaces!' => '你不能创建私有的空间',
    'You cannot create public visible spaces!' => '你不能创建公共空间',
    'You need to login to view contents of this space!' => '你需要登录才能查看这个空间的内容！',
    'Your Message' => '应用消息',
    'Your request was successfully submitted to the space administrators.' => '你的请求已成功提交给了空间管理。',
    '{email} is not valid!' => '{email} 无效!',
    '<strong>About</strong> the Space' => '',
    '<strong>About</strong> your membership' => '',
    '<strong>Space</strong> tags' => '',
    '<strong>Spaces</strong>' => '',
    'Add users without invitation' => '',
    'Administrator:' => '',
    'Any' => '',
    'Blocked users' => '',
    'By Name' => '',
    'Decline Invite' => '',
    'Find Spaces by their description or by their tags' => '',
    'Hide About Page' => '',
    'Hide Activity Sidebar Widget' => '',
    'Hide Followers' => '',
    'Hide Members' => '',
    'Homepage (Guests)' => '',
    'I want to become a member because...' => '',
    'Join' => '',
    'Max. 100 characters.' => '',
    'Member' => '',
    'Member since' => '',
    'Moderator' => '',
    'Moderator:' => '',
    'Neither..nor' => '',
    'Newest first' => '',
    'No results found!' => '',
    'Oldest first' => '',
    'Owner:' => '',
    'Pending' => '',
    'Search...' => '',
    'Select all registered users' => '',
    'Settings could not be saved!' => '',
    'Show as List' => '',
    'Shown on About Page.' => '',
    'Space Visibility' => '',
    'Try other keywords or remove filters.' => '',
    'User invitations have been added to the queue' => '',
    'User memberships have been added to the queue' => '',
    'Users has been invited.' => '',
    'Would you like to end your membership in Space {spaceName}?' => '',
    'Would you like to unfollow Space {spaceName}?' => '',
    'Would you like to unfollow {userName}?' => '',
    'Would you like to withdraw your request to join Space {spaceName}?' => '',
    '{count} members' => '',
];

==> humhub-1.14.5.tar.gz: humhub-1.14.5/protected/humhub/modules/space/messages/zh-CN/base.php <==
<?php

return [
    '<b>This space is still empty!</b>' => '<b>这个空间还是空空如也！</b>',
    '<b>This space is still empty!</b><br>Start by posting something here...' => '<b>这个空间依然是空的</b><br>开始写点什么',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>你还不是这个空间的成员，这个空间目前还没有公开内容！</b>',
    '<strong>Confirm</strong> image deletion' => '<strong>确认</strong> 删除图片',
    '<strong>Invite</strong> members' => '<strong>邀请</strong> 成员',
    '<strong>New</strong> member request' => '<strong>新</strong> 成员请求',
    '<strong>New</strong> spaces' => '<strong>新</strong>空间',
    '<strong>Request</strong> Membership' => '<strong>请求</strong> 加入空间',
    '<strong>Space</strong> followers' => '<strong>空间</strong> 关注者',
    '<strong>Space</strong> members' => '<strong>空间</strong>成员',
    '<strong>Space</strong> menu' => '<strong>空间</strong> 菜单',
    'About' => '关于',
    'Accept' => '接受',
    'Accept Invite' => '接收邀请',
    'Access to this Space is restricted. Please introduce yourself to become a member.' => '为了获得空间管理员的通过，请简短介绍一下你自己。',
    'Admin' => '管理',
    'Administrators' => '超级管理用户',
    'Archived' => '已存档',
    'As owner you cannot revoke your membership!' => '作为拥有者，你不能撤消你的会员资格',
    'Cancel' => '取 消',
    'Close' => '关 闭',
    'Color' => '颜色',
    'Could not request membership!' => '无法请求成为成员',
    'Created At' => '创建于',
    'Created By' => '创建人',
    'Decline' => '拒绝',
    'Default' => '默认',
    'Default content visibility' => '默认内容可见性',
    'Delete' => '删除',
    'Description' => '描述',
    'Do you really want to delete your profile image?' => '你真的要删除属性图片吗？',
    'Do you really want to delete your title image?' => '你真的要删除标题图片吗？',
    'Done' => '执行',
    'Email addresses' => '邮件地址',
    'Everyone can enter' => '所有人能加入',
    'Follow' => '关注',
    'Followers' => '被关注',
    'Following' => '关注',
    'Guests' => '游客',
    'Homepage' => '首页',
    'Invite' => '邀请',
    'Invite and request' => '邀请和请求',
    'Invite by email' => '通过邮件邀请',
    'Invites' => '邀请',
    'Join Policy' => '加入政策',
    'Last Visit' => '最后一次访问',
    'Login' => '登录',
    'Members' => '成员',
    'Moderators' => '版主',
    'My Space List' => '我的空间列表',
    'My space summary' => '我的空间概要',
    'Name' => '名字',
    'New user by e-mail (comma separated)' => '通过e-mail邀请新用户（以逗号分隔）',
    'New user?' => '新用户',
    'No spaces found.' => '没有发现空间。',
    'Only by invite' => '只有通过邀请',
    'Originator User ID' => '原始用户ID',
    'Owner' => '拥有者',
    'Pick users' => '选择用户',
    'Posts' => '文章',
    'Private' => '私有的',
    'Private (Invisible)' => '私有(不可见)',
    'Public' => '公共',
    'Public (Members & Guests)' => '公开 (成员 和 游客)',
    'Public (Members only)' => '公开 (仅成员)',
    'Public (Registered users only)' => '公开 (仅注册用户)',
    'Request Message' => '请求消息',
    'Role' => '角色',
    'See all' => '查看所有',
    'Send' => '发 送',
    'Settings' => '设置',
    'Show all' => '展示所有',
    'Sorry, you are not allowed to leave this space!' => '抱歉，你不允许离开该空间！',
    'Sorting' => '排序',
    'Space' => '空间',
    'Space directory' => '空间目录',
    'Space is invisible!' => '空间不可见',
    'Spaces' => '空间',
    'Status' => '状态',
    'Stream' => '动态',
    'Tags' => '标签',
    'There is no pending invite!' => '没有请求！',
    'This action is only available for workspace members!' => '此操作仅适用于空间成员！',
    'This user is already a member of this space.' => '该用户已是该空间成员。',
    'This user is not a member of this space.' => '该用户不是该空间成员。',
    'To invite users to this space, please type their names below to find and pick them.' => '邀请用户到这个空间，请键入他们的名字在下面找到并选择他们。',
    'Updated At' => '修改于',
    'Updated By' => '修改人',
    'Updated by' => '修改人',
    'User \'{username}\' is already a member of this space!' => '用户 \'{username}\' 已经是这个空间的成员了!',
    'User not found!' => '用户未找到',
    'Users' => '用户',
    'Visibility' => '可见性',
    'Visible for all (members and guests)' => '所有人可见 (成员 和 游客)',
    'You are not allowed to join this space!' => '您不可以参加这个空间！',
    'You cannot create private visible spaces!' => '你不能创建私有的空间',
    'You cannot create public visible spaces!' => '你不能创建公共空间',
    'You need to login to view contents of this space!' => '你需要登录才能查看这个空间的内容！',
    'Your Message' => '应用消息',
    'Your request was successfully submitted to the space administrators.' => '你的请求已成功提交给了空间管理。',
    '{email} is not valid!' => '{email} 无效!',
    '<strong>About</strong> the Space' => '',
    '<strong>About</strong> your membership' => '',
    '<strong>Space</strong> tags' => '',
    '<strong>Spaces</strong>' => '',
    'Add users without invitation' => '',
    'Administrator:' => '',
    'Any' => '',
    'Blocked users' => '',
    'By Name' => '',
    'Create new link' => '',
    'Decline Invite' => '',
    'Find Spaces by their description or by their tags' => '',
    'Hide About Page' => '',
    'Hide Activity Sidebar Widget' => '',
    'Hide Followers' => '',
    'Hide Members' => '',
    'Homepage (Non-members)' => '',
    'I want to become a member because...' => '',
    'Invite by link' => '',
    'Invite link' => '',
    'Join' => '',
    'Max. 100 characters.' => '',
    'Member' => '',
    'Member since' => '',
    'Moderator' => '',
    'Moderator:' => '',
    'Neither..nor' => '',
    'Newest first' => '',
    'No results found!' => '',
    'Oldest first' => '',
    'Owner:' => '',
    'Pending' => '',
    'Please note that any links you have previously created will become invalid as soon as you create a new one. Would you like to proceed?' => '',
    'Search...' => '',
    'Select all registered users' => '',
    'Send the link via email' => '',
    'Settings could not be saved!' => '',
    'Show as List' => '',
    'Shown on About Page.' => '',
    'Space Visibility' => '',
    'The default homepage for members of this Space' => '',
    'The default homepage for non-members and guests visiting this Space' => '',
    'The secure link has been copied in your clipboard!' => '',
    'Try other keywords or remove filters.' => '',
    'User invitations have been added to the queue' => '',
    'User memberships have been added to the queue' => '',
    'Users has been invited.' => '',
    'Would you like to end your membership in Space {spaceName}?' => '',
    'Would you like to unfollow Space {spaceName}?' => '',
    'Would you like to unfollow {userName}?' => '',
    'Would you like to withdraw your request to join Space {spaceName}?' => '',
    'You can also invite external users by email, which are not registered now. Just add their e-mail addresses separated by comma.' => '',
    'You can invite external users who are currently not registered via link. All you need to do is share this secure link with them.' => '',
    '{count} members' => '',
];
